#
# spec file for package mrouted
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2018-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mrouted
Version:        4.5
Release:        1.1
Summary:        An implementation of the DVMRP multicast routing protocol
License:        BSD-3-Clause AND BSD-4-Clause
Group:          Productivity/Networking/Routing
URL:            https://github.com/troglobit/mrouted
#Git-Clone:     https://github.com/troglobit/mrouted.git
Source:         https://github.com/troglobit/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         harden_mrouted.service.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
%{?systemd_requires}

%description
Mrouted is an implementation of the Distance-Vector Multicast Routing
Protocol (DVMRP), an earlier version of which is specified in RFC-1075.

Mrouted turns a UNIX workstation into a DVMRP multicast router with tunnel
support, in order to cross non-multicast-aware routers.  The tunnels are
virtual point-to-point, IP-IP tunnel, links between a pair of mrouted routers.

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fiv
%configure --with-systemd=%{_unitdir}
%make_build

%install
%make_install prefix=%{_prefix}
install -D -m0644 mrouted.conf %{buildroot}/%{_sysconfdir}/mrouted.conf
rm -rf %{buildroot}/%{_datadir}/doc

%preun
%service_del_preun mrouted.service

%postun
%service_del_postun mrouted.service

%pre
%service_add_pre mrouted.service

%post
%service_add_post mrouted.service

%files
%doc ChangeLog.md README.md
%license LICENSE
%{_sbindir}/map-mbone
%{_sbindir}/mrinfo
%{_sbindir}/mroutectl
%{_sbindir}/mrouted
%{_sbindir}/mtrace
%config %{_sysconfdir}/mrouted.conf
%{_mandir}/man8/map-mbone.8%{?ext_man}
%{_mandir}/man8/mrinfo.8%{?ext_man}
%{_mandir}/man8/mrouted.8%{?ext_man}
%{_mandir}/man8/mtrace.8%{?ext_man}
%{_mandir}/man5/mrouted.conf.5%{?ext_man}
%{_mandir}/man8/mroutectl.8%{?ext_man}
%{_unitdir}/mrouted.service

%changelog
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 4.5
  Fixes
  * Ignore IGMP proxy querys (src ip: 0.0.0.0), they must never
    win a querier election.
  * Fix compat read location and new location for mrouted.genid
  * Fix "non-decreasing" generation id, must increment on each
    restart.
  Changes
  * Add support for configurable IGMP query response interval.
  * Add support for configurable IGMP querier timeout.
  * New join-group <group> phyint option for cases where an IGMP
    snooping switch blocks flooding of multicast to the port where
    mrouted is connected.
  * On startup and reconf, log why we skip disabled interfaces.
  * Change to always log when assuming the IGMP querier role.
* Thu Nov  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 4.4
  Changes
  * Rename tunnel vifs, from base interface, to use the Linux
    kernel naming; dvmrpN, where N is the VIF number. Other
    kernels may handle this differently.
  * Logging to stdout now always prefixes messages with the daemon
    ident.
  * If adding a tunnel VIF and Linux does not have ipip.ko loaded,
    mrouted logs this as a warning message.
  * Add test for IPIP tunnels.
  * Refactored linked-list handling in unicast route engine
    (internal).
  * Drop experimental RSRR feature. It is very likely unused these
    days, seeing as the draft memo never made it into widespread
    use. It is also not working properly with multiple instances of
    mrouted.
  Fixes
  * Issue #52: IP-IP tunnels don't work anymore. Somewhere in the
    big refactor for the mrouted v4.x series, the tunnel directive
    in the .conf parser was never adapted to the new internals.
  * Fix a 10 year old regression after a linked-list refactor,
    causing off-by-one (loss of one) in unicast route distribution
    Which in turn cause VIF tunnels to malfunction.
* Wed Oct  6 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_mrouted.service.patch
* Wed Sep 22 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 4.3
  Changes
  * Add support for `-i,--ident=NAME` to change identity of an
    instance.
  * Add support for `-p,--pidfile=FILE` to override default PID
    file.
  * Touch PID file at SIGHUP to acknowledge done reloading .conf
    file.
  * Add support for `-t,--table-id=ID`, multicast routing tables.
  * Add support for `-u,--ipc=FILE` to override
    `/var/run/mrouted.sock` file, used for communication with
    `mroutectl`.
  Fixes
  * Fix segfault when parsing `phyint` lines in .conf file
    interface cannot be found, e.g.,
    `phyint eth1 static-group 225.1.2.5`.
  * Prevent cascading warnings when phyint interface names cannot
    be found.
* Thu Jan  7 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2
  Major bug fix and feature release. Support for static routes and
  improved configuration support for IGMP.
  Changes
  * Support for controlling IGMP Last Member Query Count using
    the igmp-robustness setting in mrouted.conf, default 2.
  * Support for tuning the IGMP Last Member Query Interval using
    a new setting igmp-query-last-member-interval <1-1024>.
  * Support for static multicast routing (*,G), similar to SMCRoute
  * New phyint static-group GROUP setting in mrouted.conf
  * multiplestatements supported, but no ranges (yet).
  * Proper tracking of lower-version host members (IGMP), when a
    lower version host is detected for a group, a timer is set
    according to RFC3376, and while in this compat mode
    higher-version IGMP is not allowed to change state. E.g., in
    IGMPv1 compat, IGMPv2 LEAVE is * ignored for the group,
    similar to the phyint being in igmpv1 mode.
  * Allow IGMP reports from source address 0.0.0.0, required as
    per RFC3376, sec. 4.2.13, not supported until now. This
    should greatly improve interop with IGMP snooping switches and
    DHCP clients that have not yet received a lease
  * Improved support for running mroutectl under watch(1). No more
    artifacts due to unknown ANSI escape sequences to probe width
  * Delayed PID file creation until after initial startup delay,
    there is nobody home until after that delay, so no point in
    announcing availability until after that
  Fixes
  * IGMPv3 membership reports were parsed incorrectly.
    The problem affects users that use source specific multicast
    join, i.e., (S,G) join/leave using IGMPv3. Support for
    IGMPv3 was introduced in mrouted v4.0
  * Malformed group-specific IGMP query. The IGMP header no longer
    had the group field set, despite the query being addressed to
    a specific group. Regression introduced in v4.0
  * The optional phyint flag igmpv3 did not work.
  * Fix buffer overrun in descriptor poll() handling
  * Fix double-close on SIGHUP, Linux systems only
  * Various non-critical memory leak fixes, critical for no-MMU
    systems
* Fri Oct  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1
  Changes
  * Automatically detect and add `altnet` to interfaces with
    multiple addresses, possible thanks to work on.
  * Reduce number of exposed aliases to debug sub-systems in
    online help text and man page. Only primary name, as of
    mrouted v3.9-beta3.
  * Removed noisy `timer` sub-system from `-d all`, use
    `-d all, timer`.
  Fixes
  * Fix update of `mrouted.genid` on SIGHUP and reboot.  mrouted
    replaced contents with the value zero (0), causing a zero
    genid in DVMRP as well, which likely caused peering issues
    with some implementations
  * Workaround for older autoconf without `--runstatedir` support
  * Fix double free in `pidfile()`
  * Cannot disable multicast routing in kernel: Permission denied
    when starting up.
  * Refactor interface probing and bringup. Fixes issue with the
    `no phyint` config option not working, introduced in v4.0.
  * Fix bad path for mrouted.genid, should be in `/var/lib/misc`
    on Linux and `/var/db` on *BSD.
  * Document and improve error message when running out of IGMP
    groups on Linux.
  * Detect and warn if multicast ingresses an unknown vif
* Wed Jun 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.0
  Major release with full IGMPv3 (ASM) support and a new
  mroutectl tool.
  Note: command line options have been changed!
  Changes
  * Support for IGMPv3, both sending queries and accepting
    membership reports.
  * Support for configurable IGMP query interval.
  * Support for configurable IGMP robustness variable.
  * Incompatible command line option refactor.
  * New directive in mrouted.conf: no phyint, reverses the default
    behavior of mrouted. Interfaces can then selectively be enabled
  * Support for disabling the IP router-alert option
    md unit file.
  * Introduce mroutectl, a helpful tool to interact with mrouted.
    This completely replaces mrouted.cache and mrouted.dump,
    including SIGUSR1 and SIGUSR2 signals, which are now ignored.
  * The mrouted.pid file, and the new mrouted.sock file, are now
    located in /var/run
  * Major cleanup of logging directives read from the command line,
    and from mroutectl. Use -d ?, and -l ? to list alternatives.
  Fixes
  * Fix #20: Replace obsolete gethostbyname() w/ getaddrinfo()
  * Fix #25: Save mrouted.genid to persistent store in /var/lib
    instead of /var/run
  * Fixed libc portability issues, e.g. GNU:isms like %%m etc.
  * Import OpenBSD fix to daemon() equivalent, use /dev/null for
    stdin, stdout and stderr.
  * Use clock_gettime(), with monotonic clock, instead of the
    unsafe gethostbyname(), for all non-date-printing code paths.
    Only for mrouted, other tools have not been changed.
  * Fix lots of invalid format specifiers
  * Fix memory leaks in mrouted on SIGHUP.
- Package systemd service file
* Fri Jun 29 2018 mardnh@gmx.de
- Fix license
* Mon Jun 18 2018 mardnh@gmx.de
- Initial package, version 3.9.8
